@@ -1187,7 +1187,9 @@ void fileManagerView::fmTransferSelectedFiles(QString& destDir)
 
 int fileManagerView::fmUploadFileList(QString& destination, QPtrList<FileInfos> *file_info_list)
    {
-   return(internal_fileview->ioIntf->exec_TransferUpload(destination, file_info_list));
+   int ret;
+   ret = internal_fileview->ioIntf->exec_TransferUpload(destination, file_info_list);
+   return(ret);
    }
 
 void fileManagerView::sUpOneLevelClicked(void)
@@ -1224,3 +1226,8 @@ QString fileManagerView::currentDirectory(void)
    {
    return(internal_fileview->currentDirectory());
    }
+
+bool fileManagerView::isProcessing()
+   {
+   return(internal_fileview->ioIntf->isProcessing());
+   }
