@@ -185,6 +185,7 @@ int IOInterface::internal_exec_TransferToiFP(QString& remoteDest, QPtrList<FileI
    ret = IO_INTF_OK;
    for (fi_temp = local_file_list->first(); fi_temp; fi_temp = local_file_list->next())
       {
+      processingFiles = TRUE;
       fi_temp->setProcessed(FALSE);
       fileName = fi_temp->FileName();
       if (mbret != QMessageBox::YesAll)
@@ -219,6 +220,11 @@ int IOInterface::internal_exec_TransferToiFP(QString& remoteDest, QPtrList<FileI
       if ((ret != IO_INTF_OK) && (ret != IO_INTF_USER_CANCEL))
          {
          lastErrString = QString(ifpgui_ifp_error_message(ret));
+         if (pginfo.pgw != NULL)
+            {
+            delete pginfo.pgw;
+            pginfo.pgw = NULL;
+            }
          showInfoMsgBox(QObject::tr("iRiver Upload File Status"), lastErrString);
          break;
          }
@@ -226,9 +232,17 @@ int IOInterface::internal_exec_TransferToiFP(QString& remoteDest, QPtrList<FileI
          {
          break;
          }
+      processingFiles = FALSE;
       }
-   delete pginfo.pgw;
+   processingFiles = FALSE;
+   if (pginfo.pgw != NULL)
+      {
+      delete pginfo.pgw;
+      pginfo.pgw = NULL;
+      }
+   processingFiles = TRUE;
    ifp_read_file_tree();
+   processingFiles = FALSE;
    return(ret);
    }
 
@@ -326,6 +340,7 @@ int IOInterface::internal_exec_TransferFromiFP(QString& localDest, QPtrList<File
    ret = IO_INTF_OK;
    for (fi_temp = remote_file_list->first(); fi_temp; fi_temp = remote_file_list->next())
       {
+      processingFiles = TRUE;
       fi_temp->setProcessed(FALSE);
       if (mbret != QMessageBox::YesAll)
          {
@@ -368,7 +383,9 @@ int IOInterface::internal_exec_TransferFromiFP(QString& localDest, QPtrList<File
          {
          break;
          }
+      processingFiles = FALSE;
       }
+   processingFiles = FALSE;
    delete pginfo.pgw;
    return(ret);
    }
@@ -602,6 +619,7 @@ int FileInterface::exec_GetDirectoryListing(QString dirName, QPtrList<FileInfos>
       return(IO_INTF_OK);
       }
 
+   processingFiles = TRUE;
    files = thisDir.entryInfoList();
    if (files)
       {
@@ -643,6 +661,7 @@ int FileInterface::exec_GetDirectoryListing(QString dirName, QPtrList<FileInfos>
             }
          }
       }
+   processingFiles = FALSE;
    return(IO_INTF_OK);
    }
 
@@ -693,13 +712,16 @@ int iFPInterface::ifp_connect(bool showError)
 
    if (ret == IO_INTF_OK)
       {
+      processingFiles = TRUE;
       if ((ret = ifp_read_file_tree()) != IO_INTF_OK)
          {
          showInfoMsgBox(QObject::tr("Error"), QObject::tr(iFPNotConnectedMsg));
          fprintf(stderr, "Could not communicate with iRiver device.\n");
          fprintf(stderr, "Try unplugging the USB link, powering off the device, and plugging it back in.\n");
+         processingFiles = FALSE;
          return(ret);
          }
+      processingFiles = FALSE;
       }
    else
       {
@@ -764,17 +786,22 @@ int iFPInterface::exec_Mkdir(QString& baseDir, QString& newDir)
 
    if (ret == QDialog::Accepted)
       {
+      processingFiles = TRUE;
       slash2backslash(newDir);
       qcfilename = newDir.utf8();
       ret = ifpgui_ifp_mkdir(&ifp_dev, qcfilename);
       if (ret != IO_INTF_OK)
          {
          lastErrString = QString("Could not make directory [%1] on iRiver device.").arg(newDir);
+         processingFiles = FALSE;
          return(-1);
          }
+      processingFiles = TRUE;
       ifp_read_file_tree();
+      processingFiles = FALSE;
       return(IO_INTF_OK);
       }
+   processingFiles = FALSE;
    return(IO_INTF_USER_CANCEL);
    }
 
@@ -806,6 +833,7 @@ int iFPInterface::exec_Rename(const QString& oldName, const QString& newName)
       return(-1);
       }
 
+   processingFiles = TRUE;
    slash2backslash(tmp_oldName);
    slash2backslash(tmp_newName);
    qcfilename_old = tmp_oldName.utf8();
@@ -814,9 +842,12 @@ int iFPInterface::exec_Rename(const QString& oldName, const QString& newName)
    if (ret != IO_INTF_OK)
       {
       lastErrString = QObject::tr("Could not rename  %1  to  %2  on iRiver device.").arg(oldName).arg(newName);
+      processingFiles = FALSE;
       return(-1);
       }
+   processingFiles = TRUE;
    ifp_read_file_tree();
+   processingFiles = FALSE;
    return(IO_INTF_OK);
    }
 
@@ -849,6 +880,7 @@ int iFPInterface::exec_Delete(QPtrList<FileInfos> *file_info_list)
 
    for (fi_temp = file_info_list->first(); fi_temp; fi_temp = file_info_list->next())
       {
+      processingFiles = TRUE;
       lastErrString = "";
       fi_temp->setProcessed(FALSE);
       // remove the protocol info
@@ -857,6 +889,7 @@ int iFPInterface::exec_Delete(QPtrList<FileInfos> *file_info_list)
       if (ret != IO_INTF_OK)
          {
          lastErrString = QObject::tr("Remote file protocol not supported \"%1\"").arg(internal_get_ProtocolStr(filename));
+         processingFiles = FALSE;
          return(-1);
          }
       slash2backslash(filename);
@@ -918,8 +951,11 @@ int iFPInterface::exec_Delete(QPtrList<FileInfos> *file_info_list)
          // dispaly error
          showInfoMsgBox(QObject::tr("iRiver Delete Status"), lastErrString);
          }
+      processingFiles = FALSE;
       }
+   processingFiles = TRUE;
    ifp_read_file_tree();
+   processingFiles = FALSE;
    return(IO_INTF_OK);
    }
 
@@ -968,7 +1004,9 @@ int iFPInterface::exec_GetDirectoryListing(QString dirName, QPtrList<FileInfos>
       }
 
    slash2backslash(dirName);
+   processingFiles = TRUE;
    ret = iFPgetFileList(dirName, file_info_list);
+   processingFiles = FALSE;
 
    return(ret);
    }
