@@ -403,10 +403,14 @@ static inline int _ifp_dir_close(struct ifp_device * dev)
 //bytes written (if the whole block wasn't written).
 static inline int _ifp_file_upload(struct ifp_device * dev, int bytes)
 {
-	int i;
-	i = ifp_control_send(dev, IFP_FILE_UPLOAD, bytes, 0, NULL);
-	if (i >= 0 && i == bytes) {
-		return 0;
+	int i, ret, cnt;
+	for (cnt = 0; cnt < 3; cnt++) {
+		i = ifp_control_send(dev, IFP_FILE_UPLOAD, bytes, 0, NULL);
+		if ((i > 0 && i == bytes) || (i == 0)) {
+			return i;
+		}
+		ifp_dbg("FAILED with error %d.  retrying %d of 3", i, cnt + 1);
+		ifp_os_sleep(100);
 	}
 	return i < 0 ? i : -1;
 }
@@ -757,7 +761,10 @@ int ifp_file_upload(struct ifp_device * dev, void * p, int n)
 	i = _ifp_push(dev, p, n);
 	ifp_err_jump(i, out, "push failed");
 	i = _ifp_file_upload(dev, n);
-	ifp_err_jump(i, out, "upload control code failed");
+	if (i != n) {
+		ifp_dbg("_ifp_file_upload returned %d -- continue anyway on 0", i);
+		ifp_err_jump(i, out, "upload control code failed");
+	}
 
 out:
 	return i;
@@ -769,7 +776,7 @@ int ifp_file_flush(struct ifp_device * dev)
 	int i;
 	int status;
 	int n = 0;
-	int const obsene_limit = 1000;
+	int const obsene_limit = 100;
 
 	do {
 		//Sleep even on the first loop.. it's good for soul.. call it "kerma"
@@ -789,7 +796,7 @@ int ifp_file_flush(struct ifp_device * dev)
 			//done
 			return 0;
 		}
-		if (n == 5) {
+		if (n == 10) {
 			ifp_wrn("[ifp_file_flush] waiting for device 'ready'.");
 			ifp_wrn("[ifp_file_flush] (normally it doesn't take this long).");
 		}
